@@ -1,5 +1,4 @@
 package Alien::SeqAlignment::edlib;
-$Alien::SeqAlignment::edlib::VERSION = '0.02';
 use parent qw( Alien::Base );
 use Alien::Build::Plugin::Build::CMake; ## uses cmake build
 use Path::Tiny;
@@ -43,7 +42,7 @@ Alien::SeqAlignment::edlib
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -58,13 +57,15 @@ To execute the alignment using the commande line tool:
 =head1 DESCRIPTION
 
 This distribution provides edlib so that it can be used by other
-Perl distributions that are on CPAN.  It does this by first trying to
-detect an existing install of parasail on your system.  If found it
-will use that.  If it cannot be found, the source code will be downloaded
-from the internet and it will be installed in a private share location
-for the use of other modules. The build provides the static and shared 
-libraries, but also the command line aligner (edlib-aligner, not currently
-available in Windows).
+Perl distributions that are on CPAN.  The source code will be downloaded
+from the edlib github repo, and if that fails it will use the location of a
+fork but the author of this module. Contrary to other Alien modules, this one
+will not test for a prior install of the edlib library, but will install 
+from source into a private share location for the use by other modules. 
+This strategy will avoid overwritting prior  system installs of the edlib
+library, and is guaranteed to use the latest version of edlib. 
+The build provides the static and shared libraries, but also the CLI aligner 
+(edlib-aligner, not currently available in Windows). 
 
 =head1 NAME
 
@@ -104,18 +105,36 @@ primary use is to compute edit distances and alignments over small
 (255 characters or fewer) alphabets as they occur in bioinformatic
 applications.
 
-=item L<https://metacpan.org/pod/Text::Levenshtein::Edlib>
+=back
+
+=over 4
+
+=item L<Text::Levenshtein::Edlib|https://metacpan.org/pod/Text::Levenshtein::Edlib>
+
 An XS library that also wraps around the edlib library and returns
 edit distances, as well as alignment paths.
 
-=item L<https://metacpan.org/pod/Text::Levenshtein::XS>
-An XS library that computes edit distances but not alignment paths.
-This module was updated last in 2016 (see also its github repository
-at: https://github.com/ugexe/Text--Levenshtein--XS/)
+=back
+
+=over 4
+
+=item L<Text::Levenshtein::XS|https://metacpan.org/pod/Text::Levenshtein::XS>
+
+An XS library that computes edit distances but not alignment paths. See also 
+its github repository at: L<https://github.com/ugexe/Text--Levenshtein--XS/>)
+
+=back
+
+=over 4
+
+=item L<Text::LevenshteinXS|https://metacpan.org/pod/Text::LevenshteinXS>
 
-=item L<https://metacpan.org/pod/Text::LevenshteinXS>
 Yet another XS implementation of Levenshtein distance over strings 
-(no alignment path). This module was last updated in 2004. 
+(no alignment path).
+
+=back
+
+=over 4
 
 =item L<Alien>
 
